import { world, system } from "@minecraft/server";

let cooldowns = {};

const COOLDOWN_TIMES = {
    "bottle_of_destiny": 10000,
    "fiery_death_game_blade": 1000,
    "stardust_power": 60000,
    "stardust_meteor": 120000
};

const positiveEffects = [
    "speed",
    "strength",
    "regeneration",
    "jump_boost",
    "fire_resistance"
];

function getRandomEffect() {
    return positiveEffects[Math.floor(Math.random() * positiveEffects.length)];
}

function applyMeteorEffects(player) {
    const position = player.location;
    const radius = 10;
    const entities = world.getDimension(player.dimension.id).getEntities({
        location: position,
        maxDistance: radius,
        excludeTags: ["meteor"]
    });

    entities.forEach(entity => {
        if (entity !== player) {
            entity.runCommand("damage @s 10");
        }
    });
}

world.afterEvents.itemUse.subscribe((eventData) => {
    const player = eventData.source;
    const item = eventData.itemStack.typeId;
    const playerName = player.name;

    if (!cooldowns[playerName]) {
        cooldowns[playerName] = {};
    }

    const now = Date.now();

    switch (item) {
        case "la:bottle_of_destiny":
            if (!player.hasTag("summon")) {
                if (!cooldowns[playerName]["bottle_of_destiny"] || now - cooldowns[playerName]["bottle_of_destiny"] >= COOLDOWN_TIMES["bottle_of_destiny"]) {
                    player.runCommand("tag @s add bottle");
                    cooldowns[playerName]["bottle_of_destiny"] = now;
                } else {
                    player.runCommand("title @p actionbar §0COOLDOWN");
                }
            }
            break;

        case "la:fiery_death_game_blade":
            if (!player.hasTag("summon")) {
                if (!cooldowns[playerName]["fiery_death_game_blade"] || now - cooldowns[playerName]["fiery_death_game_blade"] >= COOLDOWN_TIMES["fiery_death_game_blade"]) {
                    player.runCommand("function changeskill");
                    cooldowns[playerName]["fiery_death_game_blade"] = now;
                } else {
                    player.runCommand("title @p actionbar §0COOLDOWN");
                }
            } else {
                if (!cooldowns[playerName]["fiery_death_game_blade"] || now - cooldowns[playerName]["fiery_death_game_blade"] >= COOLDOWN_TIMES["fiery_death_game_blade"]) {
                    player.runCommand("function changeskill");
                    cooldowns[playerName]["fiery_death_game_blade"] = now;
                }
            }
            break;

        case "la:stardust_power":
            if (!cooldowns[playerName]["stardust_power"] || now - cooldowns[playerName]["stardust_power"] >= COOLDOWN_TIMES["stardust_power"]) {
                const effect = getRandomEffect();
                player.runCommand(`effect @s ${effect} 60 60 true`);
                cooldowns[playerName]["stardust_power"] = now;
            } else {
                player.runCommand("title @p actionbar §0COOLDOWN");
            }
            break;

        case "la:stardust_meteor":
            if (!cooldowns[playerName]["stardust_meteor"] || now - cooldowns[playerName]["stardust_meteor"] >= COOLDOWN_TIMES["stardust_meteor"]) {
                player.addTag("meteor");
                cooldowns[playerName]["stardust_meteor"] = now;

                const intervalId = system.runInterval(() => {
                    applyMeteorEffects(player);
                }, 1000); // Aplica o efeito a cada 1 segundo

                system.runTimeout(() => {
                    player.removeTag("meteor");
                    system.clearRun(intervalId);
                }, 30000); // Remove após 30 segundos
            } else {
                player.runCommand("title @p actionbar §0COOLDOWN");
            }
            break;
    }
});