import { world } from '@minecraft/server';

// Listas de comandos
const positiveCommands = [
    "give @s netherite_block 1",
    "xp 80 @s",
    "summon lightning_bolt ~ ~ ~",
    "give @s golden_carrot 1",
    "give @s bow 1",
    "give @s diamond 1",
    "give @s totem_of_undying 1",
    "give @s elytra 1",
    "tp @e[r=30] ^^^6",
    "give @s emerald 10"
];

const neutralCommands = [
    "summon creeper ~ ~ ~",
    "give @s dirt 5",
    "execute at @s run summon cat ~ ~ ~",
    "execute at @s run fill ~-3 ~-3 ~-3 ~3 ~3 ~3 glass"
];

const negativeCommands = [
    "execute at @s run fill ~-5 ~-5 ~-5 ~5 ~5 ~5 spider_web",
    "summon vex ~ ~ ~",
    "tp @e[r=15] ~ ~8 ~",
    "execute at @s run fill ~-5 ~-5 ~-5 ~5 ~5 ~5 lava"
];

const positiveEffects = [
    "effect @s speed 1 8",
    "effect @s strength 1 2",
    "effect @s regeneration 1 8",
    "effect @s haste 1 8",
    "effect @s absorption 1 8",
    "execute at @s run fill ~-5 ~-5 ~-5 ~5 ~5 ~5 spider_web",
    "summon vex ~ ~ ~",
    "tp @e[r=15] ~ ~8 ~",
    "execute at @s run fill ~-5 ~-5 ~-5 ~5 ~5 ~5 lava"
];

const negativeEffects = [
    "effect @e[type=!player,r=2] slowness 2 8",
    "effect @e[type=!player,r=2] weakness 2 8",
    "effect @e[type=!player,r=2] poison 1 8",
    "effect @e[type=!player,r=2] blindness 1 8",
    "effect @e[type=!player,r=2] wither 1 10"
];

// Função para escolher um comando aleatório de uma lista
function chooseRandom(commands) {
    return commands[Math.floor(Math.random() * commands.length)];
}

// Função para aplicar probabilidades
function applyProbability(chance) {
    return Math.random() * 100 < chance;
}

// Evento para ataques de entidade
world.afterEvents.entityHitEntity.subscribe((data) => {
    const { damagingEntity, hitEntity } = data;

    // Verifica se o atacante é um jogador
    if (!damagingEntity || damagingEntity.typeId !== 'minecraft:player') return;

    // Verifica se o jogador está usando a espada la:fiery_death_game_blade
    const player = damagingEntity;
    const equipment = player.getComponent('equippable').getEquipment('Mainhand');

    if (equipment && equipment.typeId === 'la:fiery_death_game_blade') {
        // Verifica se o jogador possui tags específicas e aplica os comandos de acordo
        if (player.hasTag('modeluck2') && applyProbability(60)) {
            player.runCommand(chooseRandom(positiveCommands));
        } else if (player.hasTag('modeluck1')) {
            if (applyProbability(50)) {
                // Jogador toma dano
                player.runCommand("damage @s 500");
                player.runCommand("particle la:death_penalty");
                hitEntity.runCommand("particle la:luck_death");
            } else {
                // Entidade toma dano
                hitEntity.runCommand("damage @s 500");
                hitEntity.runCommand("particle la:death_penalty");
                player.runCommand("particle la:luck_death");
            }
        } else if (player.hasTag('modeluck3')) {
            if (applyProbability(60)) {
                player.runCommand(chooseRandom(positiveEffects));
                player.runCommand("particle la:stardust_power")
            } else {
                player.runCommand(chooseRandom(negativeEffects));
            }
        } else {
            player.runCommand(chooseRandom(negativeCommands)); // Caso nenhum modelo seja aplicado
        }
    }
});